==> openj9-18_0.33.1.orig.tar.xz: src-openj9-18-0.33.1/openj9/test/functional/Java14andUp/src/org/openj9/test/records/RecordClassTests.java <==
package org.openj9.test.records;

/*******************************************************************************
 * Copyright (c) 2020, 2020 IBM Corp. and others
 *
 * This program and the accompanying materials are made available under
 * the terms of the Eclipse Public License 2.0 which accompanies this
 * distribution and is available at https://www.eclipse.org/legal/epl-2.0/
 * or the Apache License, Version 2.0 which accompanies this distribution and
 * is available at https://www.apache.org/licenses/LICENSE-2.0.
 *
 * This Source Code may also be made available under the following
 * Secondary Licenses when the conditions for such availability set
 * forth in the Eclipse Public License, v. 2.0 are satisfied: GNU
 * General Public License, version 2 with the GNU Classpath
 * Exception [1] and GNU General Public License, version 2 with the
 * OpenJDK Assembly Exception [2].
 *
 * [1] https://www.gnu.org/software/classpath/license.html
 * [2] http://openjdk.java.net/legal/assembly-exception.html
 *
 * SPDX-License-Identifier: EPL-2.0 OR Apache-2.0 OR GPL-2.0 WITH Classpath-exception-2.0 OR LicenseRef-GPL-2.0 WITH Assembly-exception
 *******************************************************************************/

import org.testng.annotations.Test;

import org.openj9.test.utilities.RecordClassGenerator;
import org.openj9.test.utilities.CustomClassLoader;

/** 
 * Test class formatting for records classes introduced in JEP 359
 * - record class cannot be abstract
 */
@Test(groups = { "level.sanity" })
public class RecordClassTests {
    String name = "TestBadRecords";

    /* record classes cannot be abstract */
    @Test(expectedExceptions = java.lang.ClassFormatError.class)
    public void test_recordCannotBeAbstract() {
        CustomClassLoader classloader = new CustomClassLoader();
        byte[] bytes = RecordClassGenerator.generateAbstractRecord(name);
        Class<?> clazz = classloader.getClass(name, bytes);
    }
}

==> openj9-21_0.56.0.orig.tar.xz: src-openj9-21-0.56.0/openj9/test/functional/Java14andUp/src/org/openj9/test/records/RecordClassTests.java <==
package org.openj9.test.records;

/*
 * Copyright IBM Corp. and others 2020
 *
 * This program and the accompanying materials are made available under
 * the terms of the Eclipse Public License 2.0 which accompanies this
 * distribution and is available at https://www.eclipse.org/legal/epl-2.0/
 * or the Apache License, Version 2.0 which accompanies this distribution and
 * is available at https://www.apache.org/licenses/LICENSE-2.0.
 *
 * This Source Code may also be made available under the following
 * Secondary Licenses when the conditions for such availability set
 * forth in the Eclipse Public License, v. 2.0 are satisfied: GNU
 * General Public License, version 2 with the GNU Classpath
 * Exception [1] and GNU General Public License, version 2 with the
 * OpenJDK Assembly Exception [2].
 *
 * [1] https://www.gnu.org/software/classpath/license.html
 * [2] https://openjdk.org/legal/assembly-exception.html
 *
 * SPDX-License-Identifier: EPL-2.0 OR Apache-2.0 OR GPL-2.0-only WITH Classpath-exception-2.0 OR GPL-2.0-only WITH OpenJDK-assembly-exception-1.0
 */

import org.testng.annotations.Test;

import org.openj9.test.utilities.RecordClassGenerator;
import org.openj9.test.utilities.CustomClassLoader;

/** 
 * Test class formatting for records classes introduced in JEP 359
 * - record class cannot be abstract
 */
@Test(groups = { "level.sanity" })
public class RecordClassTests {
    String name = "TestBadRecords";

    /* record classes cannot be abstract */
    @Test(expectedExceptions = java.lang.ClassFormatError.class)
    public void test_recordCannotBeAbstract() {
        CustomClassLoader classloader = new CustomClassLoader();
        byte[] bytes = RecordClassGenerator.generateAbstractRecord(name);
        Class<?> clazz = classloader.getClass(name, bytes);
    }
}
